<?php

namespace OCA\DeckFlow\BackgroundJobs;

use OCP\BackgroundJob\TimedJob;
use OCA\Deck\Service\CardService;
use OCP\IConfig;
use OCP\ILogger;
use OCP\IUserManager;
use DateTime;
use DateTimeZone;

class CheckOverdueCards extends TimedJob {
    private CardService $cardService;
    private IConfig $config;
    private IUserManager $userManager;
    private ILogger $logger;

    public function __construct(CardService $cardService, IConfig $config, IUserManager $userManager, ILogger $logger) {
        parent::__construct();
        $this->cardService = $cardService;
        $this->config = $config;
        $this->userManager = $userManager;
        $this->logger = $logger;
        $this->setInterval(3600);
    }

    protected function run($argument) {
        $users = $this->userManager->search('');
        foreach ($users as $user) {
            $userId = $user->getUID();
            $rules = json_decode($this->config->getUserValue($userId, 'deckflow', 'rules', '[]'), true);
            foreach ($rules as $rule) {
                $sourceStack = $rule['source_stack'];
                $targetStack = $rule['target_stack'];
                $cards = $this->cardService->findAllCardsInStack($sourceStack);
                $now = new DateTime('now', new DateTimeZone('UTC'));

                foreach ($cards as $card) {
                    if (isset($card['duedate']) && new DateTime($card['duedate'], new DateTimeZone('UTC')) < $now) {
                        $this->cardService->updateCard($card['id'], ['stackId' => $targetStack]);
                    }
                }
            }
        }
    }
}
